**************************** TABLES AND FIGURES CONSTRUCTION FOR *******************************
**************************** Optimal Taxation of Top Labor Incomes: **************************** 
**************************** A Tale of Three Elasticities **************************************

**************************** AUTHORS:************************************************************
***********                  Thomas Piketty, Emmanuel Saez and Stefanie Stantcheva          *****
*************************************************************************************************


**************************** DATE: **************************************************************
***********                  November 14th 2012  *****************************************************
*************************************************************************************************

**************************** DESCRIPTION ********************************************************
***********                  This do file constructs table 4 
***********                  INPUT files: data_compensation_pub.dta contains the data on CEO compensation 
***********                               from Fernandes et. al. (2012) - this is NOT public data
***********                               taxes.dta (online on our websites)
***********                  OUTPUT files: table_ceocomp.tex, table_ceocomp.xls
*************************************************************************************************

clear all
set more off
cap log close

cd ...

log using ceocomp.log, replace

*************************************************** PREPARE DATA ***********************************************************
****************************************************************************************************************************

use data_compensation_pub, clear
sort country
merge country using taxes
tab _merge
drop if _merge == 2

* Note only south africa and Belgium dont merge = need to find top tax rates for 2006 for them
replace mtr = 0.4 if country == "South Africa"
replace mtr = 0.74 if country == "Belgium" 
replace mtr = 1-(1-mtr)/(1+.125) if country == "Canada"

*(OECD actually says 50% top rate and average 7% local rate and 13.07% employee SSC, without reduction, and according to Taxing Wages, the reduction on top incomes
* is such that top employer contribution is 28.5% after reduction, VAT is 21%, hence MTR = 74%)

* We actually decide to drop South Africa, since it's not an OECD country and is an outlier in addition

drop if country == "South Africa"

tab country, gen(country_)
tab ff_industry_nr, gen(industry)

*************************************************** DEFINE VARIABLES ***********************************************************
********************************************************************************************************************************

gen lsales = log(sales_usd)

local countrycontrols country_2 - country_13
local firmcontrols lsales tobinq_w roa_w leverage_w return_w stdev_return_w industry2 - industry12
local firmcontrols2 lsales industry2 - industry12
gen age_ceo2 = age_ceo^2
gen time_in_role_ceo2 = time_in_role_ceo^2
local ceocontrols  age_ceo age_ceo2 time_in_role_ceo age_ceo2 dummy_college

* Compensation variables: 
* salary_ceo equity_incentives_ceo other_pay_ceo non_equity_incentives_ceo (bonus) total_pay_ceo

* Governance variables: 
* Insider ownership (close): according to Fernandez et al, more is better: more instrinsic reward and more monitoring by block holders?
* Indep ratio = independent directors as fraction of the board
* Is CEO also board chairman? (ceo_chairman)1 = bad recode this
gen ceo_nchairman = . 
replace ceo_nchairman = 0 if ceo_chairman == 1
replace ceo_nchairman = 1 if ceo_chairman == 0
* Board positions at other companies of other board members. More means less governance (quoted_board_current_board)
* Institutional ownership: I think this is the variable own_all (matches the summary stats in paper). more = better

gen ret = log(1-mtr)

gen ltotal = log(total_pay_ceo)
gen lsalary = log(salary)
gen lequitypay = log(equity_incentives_ceo)
gen lother = log(other_pay_ceo)
gen lbonus = log(non_equity_incentives_ceo) if non_equity_incentives_ceo !=0
replace lbonus = log(1+non_equity_incentives_ceo) if non_equity_incentives_ceo ==0
gen lequitybonus = log(equity_incentives_ceo + non_equity_incentives_ceo) if equity_incentives_ceo + non_equity_incentives_ceo != 0
replace lequitybonus = 0 if equity_incentives_ceo + non_equity_incentives_ceo == 0

gen usdummy = (country == "United States")


** Index construction:
*****************************************************************************************************************************************************

rename ceo_nchairman nchair

quietly summ quoted_board_current_board, detail
gen nmultiple = . 
replace nmultiple = 1 if quoted_board_current_board <= r(p50)
replace nmultiple = 0 if quoted_board_current_board > r(p50) & quoted_board_current_board != . 
quietly summ nmultiple, detail
gen z_nmultiple = (nmultiple - r(mean))/r(sd)

quietly summ close, detail
gen close_temp = . 
replace close_temp = 0 if close <= r(p50)
replace close_temp = 1 if close > r(p50) & close !=. 
quietly summ close_temp, detail 
gen z_close = (close_temp - r(mean))/r(sd)
drop close_temp

quietly summ own_all, detail
gen own_all_temp = . 
replace own_all_temp = 0 if own_all <= r(p50)
replace own_all_temp = 1 if own_all > r(p50) & own_all !=. 
quietly summ own_all_temp, detail 
gen z_own_all = (own_all_temp - r(mean))/r(sd)
drop own_all_temp

foreach var in indep_ratio nchair {
quietly summ `var', detail
gen z_`var' = (`var' - r(mean))/r(sd)
}

gen index_temp = z_indep_ratio + z_own_all + z_nchair + z_close + z_nmultiple
quietly summ index_temp, detail
gen index = (index_temp - r(mean))/r(sd)
* gen index = index_temp
gen ret_index = ret*index

drop index_temp z_*

*** Index 1: 
**************************************************************************

foreach var in indep_ratio close own_all nchair quoted_board_current_board {
quietly summ `var', detail
gen z_`var' = (`var' - r(mean))/r(sd)
}

gen index1_temp = z_indep_ratio + z_own_all + z_nchair - z_quoted_board_current_board + z_close
quietly summ index1_temp, detail
gen index1 = (index1_temp - r(mean))/r(sd)
gen ret_index1 = ret*index1

drop index1_temp


*** Index 3: 
**************************************************************************

gen index2_temp = z_indep_ratio + z_own_all + z_nchair - z_quoted_board_current_board 
quietly summ index2_temp, detail
gen index2 = (index2_temp - r(mean))/r(sd)
gen ret_index2 = ret*index2

drop index2_temp

*************************************************** SPEC 1: ltotal pay on retention rate ***********************************************************
****************************************************************************************************************************************************

quietly reg ltotal ret, cluster(country)
estimates store col1

*************************************************** SPEC 2: ltotal pay on retention rate and Murphy controls except governance**********************
****************************************************************************************************************************************************

quietly reg ltotal ret `firmcontrols', cluster(country)
estimates store col2

*************************************************** SPEC 3: ltotal pay on retention rate, Murphy controls and governance**********************
****************************************************************************************************************************************************

quietly reg ltotal ret index `firmcontrols2', cluster(country)
estimates store col3

*************************************************** SPEC 4: retention rate, Murphy controls, governance and interactions **********************
****************************************************************************************************************************************************

quietly reg ltotal ret index ret_index `firmcontrols2', cluster(country)
estimates store col4

*************************************************** SPEC 5: Log Salary       **********************
****************************************************************************************************************************************************

quietly reg lsalary ret index ret_index `firmcontrols2', cluster(country)
estimates store col5

*************************************************** SPEC 6: Log Salary       **********************
****************************************************************************************************************************************************

quietly reg lequitybonus ret index ret_index `firmcontrols2', cluster(country)
estimates store col6


*************************************************** CREATE TABLE                                                             **********************
****************************************************************************************************************************************************

label var ret "Log Retention Rate"
label var index "Governance Index"
label var index1 "Governance Index 2"
label var index2 " Governance Index 3"
label var ret_index "Retention Rate * Governance Index"
label var ret_index1 "Retention Rate * Governance Index 2"
label var ret_index2 "Retention Rate * Governance Index 3"

outreg2 [col1] ret using table_ceocomp, tex excel replace nocons nonote se r2 dec(2) ctitle([1], Log Total Pay) addnote(Standard Errors in brackets) label alpha(0.01, 0.05, 0.10) symbol(***, **, *) slow(2000)
outreg2 [col2] ret using table_ceocomp, tex excel append nocons nonote se r2 bdec(2) ctitle([2], Log Total Pay) slow(2000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [col3] ret index using table_ceocomp, tex excel append nocons nonote se r2 bdec(2) ctitle([3], Log Total Pay) slow(2000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [col4] ret index ret_index using table_ceocomp, tex excel append nocons nonote se r2 bdec(2) ctitle([4], Log Total Pay) slow(2000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [col5] ret index ret_index using table_ceocomp, tex excel append nocons nonote se r2 bdec(2) ctitle([5], Log Salary) slow(2000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [col6] ret index ret_index using table_ceocomp, tex excel append nocons nonote se r2 bdec(2) ctitle([6], Log Equity Pay and Bonus) slow(2000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)

cap log close 
