**************************** TABLES AND FIGURES CONSTRUCTION FOR *******************************
**************************** Optimal Taxation of Top Labor Incomes: **************************** 
**************************** A Tale of Three Elasticities **************************************

**************************** AUTHORS:************************************************************
***********                  Thomas Piketty, Emmanuel Saez and Stefanie Stantcheva          *****
*************************************************************************************************


**************************** DATE: **************************************************************
***********                  November 14th 2012  *****************************************************
*************************************************************************************************

**************************** DESCRIPTION ********************************************************
***********                  This do file performs a robustness check for table 3 using only the 
***********                  a subsample of the Execucomp firms post 1992, supposed to match the Forbes 800 for
***********                  the pre-1991 period.
***********                  INPUT files: working2.dta contains all the data and is constructed from 
***********                               the raw data through the DO file "Dataset_creation", and then merging with 
***********                               revenue.dta (which contains only the revenues for each firm from COMPUSTAT)
***********                               NOTE: the raw data is NOT publicly available but needs to be downloaded
***********                               from the WRDS website, with user access. The datasets to be downloaded
***********                               are explained in the paper Appendix. The Forbes 800 data is to be requested
***********                               US_CPI.dta: available from the authors
***********                               UStaxes.dta: available from the authors
***********                               top_brackets.dta: available from the authors
***********                  OUTPUT files: table_test_800.xlm, table_test_800.tex
*************************************************************************************************


clear
cap log close
set more off

set mem 1000m
set matsize 3000

estimates drop _all

# delimit cr 

* cd "C:\Users\Stefanie\Documents\My Dropbox\thirdelasticity\empirical\Compustat\"

use working2.dta, clear

log using BM_10012012_tables_log_periods_800.log, replace

sort fyear

merge fyear using US_CPI
drop if _merge == 2
drop _merge

sort fyear
merge fyear using UStaxes
drop if _merge == 2
drop _merge

sort fyear
merge fyear using top_brackets
drop _merge
replace bracket = bracket/1000


******************** Financial Variable definitions **************************

* BM measure 1 of performance: net income 
* BM measure 2 of performance: return on equity (called income/assets in their paper)
* at = total assets
* ni = net income
* roe = ni/at
* BM measure 3 of performance: change in shareholder wealth. Change in shareholder wealth = beginning of year equity value times return on common equity
* (will compute both market and book value).
* But since firm fixed effects in the regressions, shareholder wealth should be in levels, but not changes. Hence, shareholder wealth = market value of equity

* Check Kenn French definitions: http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/Data_Library/variable_definitions.html
* Firm value (market) = market value of equity + book value of debt 
* = (number of common shares outstanding (COMPUSTAT item 25) times the average price per share during year (COMPUSTAT item 199)) + book value of debt. 
* Book value of equity is equal to total assets (COMPUSTAT item 6), minus total liabilities (COMPUSTAT item 181) and preferred stock (item 10) 
* plus deferred taxes (item 35) and convertible debt (item 79)). Following Fama and French (2000), when preferred stock is missing, it is replaced 
* by the redemption value of preferred stock (item 56). 
* Firm book value = book value of equity + book value of total debt.
* Total debt is defined as the sum of long-term debt (COMPUSTAT item 9) and the current liabilities (COMPUSTAT item 34).

* Common shares outstanding: csho
* Price close annual calendar:   prcc_c
* Total liabilities: lt
* Debt in current liabilities : dlc
* Preferred stock at redemption value : pstkrv
* Net Deferred tax liability: txndbl
* Debt convertible: dcvt
* labor and related expenses: xlr
* only wage and salaries expenses: xstfws
* total employees: emp

* Constructed variables: 
* Market value of equity = mve = shareholder wealth
* Market value of firm = mvf
* Book value of firm = bvf
* Book value of equity = bve
* Change in Shareholder wealth = roe*mve
* average wage in firm: wage = xlr/emp 
* other measure using only wages and salaries: wage2 = xstfws/emp
*************************************************************

* cpi = US CPI index
replace cpi = cpi/100

replace ni = ni/cpi
replace at = at/cpi
gen roe = ni/at
gen mve = csho*(prcc_c/cpi)
gen shwealth = mve
gen logshwealth = log(shwealth)

** First create a dataset of Execucomp with only the top 800, comparable to Forbes

keep if _merge_execucomp == 3

collapse ni at mve revt, by(fyear cusip6)
gen flag800 = 0 
gen at_neg = -at
sort fyear at_neg
by fyear: gen rank = _n 
replace flag800 = 1 if rank <= 500 
drop rank at_neg

gen ni_neg = - ni
sort fyear ni_neg
by fyear: gen rank = _n 
replace flag800 = 1 if rank <= 500 
drop rank ni_neg

gen mve_neg = - mve
sort fyear mve_neg
by fyear: gen rank = _n 
replace flag800 = 1 if rank <= 500 
drop rank mve_neg

gen revt_neg = - revt
sort fyear revt_neg
by fyear: gen rank = _n 
replace flag800 = 1 if rank <= 500 
drop rank revt_neg

keep fyear cusip6 flag800
sort fyear cusip6

save working_800.dta, replace

use working.dta, clear

sort fyear

merge fyear using US_CPI
drop if _merge == 2
drop _merge

sort fyear
merge fyear using UStaxes
drop if _merge == 2
drop _merge

sort fyear
merge fyear using top_brackets
drop _merge
replace bracket = bracket/1000

sort fyear cusip6
merge fyear cusip6 using working_800
tab _merge
drop _merge

keep if flag800 == 1 | _merge_forbes == 3

* cpi = US CPI index
replace cpi = cpi/100

replace ni = ni/cpi
replace at = at/cpi
gen roe = ni/at
gen mve = csho*(prcc_c/cpi)
gen shwealth = mve
gen logshwealth = log(shwealth)


********************************************************************
********************************************************************
drop roe
gen roe = ni
replace roe = log(roe)

* Try to replace log shwealth with its deviation from mean, by year
sort fyear

by fyear: egen logshwealth_average = mean(logshwealth)
replace logshwealth = logshwealth- logshwealth_average

by fyear: egen roe_average = mean(roe)
replace roe = roe - roe_average

# delimit ; 

* drop outliers

sort fyear
by fyear: egen roe_top = pctile(roe), p(99.5)
by fyear: egen roe_bottom = pctile(roe), p(0.5)

replace roe = . if roe >= roe_top | roe <= roe_bottom
drop roe_top roe_bottom

sort fyear
by fyear: egen lsh_top = pctile(logshwealth), p(99.5)
by fyear: egen lsh_bottom = pctile(logshwealth), p(0.5)

replace logshwealth = . if logshwealth >= lsh_top | logshwealth <= lsh_bottom
drop lsh_top lsh_bottom ; 

# delimit cr


******************** CEO variables definitions ****************

* Make names of execucomp and Forbes CEO variables consistent.
* Drop those executives who are non CEOs in execucomp

drop if _merge_execucomp == 3 & ceoann == ""

* Forbes variables: 
* cashpay, optiongains,	otherpay, totalpay ( I *think* in thousands).
* tenure, ceotenure, age_temp

* Execucomp variables: 
* age
* Tenure in company: 
gen date = mdy(12,31,fyear)
gen tenure_temp = (date - joined_co)/365.25 
replace tenure_temp = round(tenure_temp,1)
* Tenure as CEO: 
gen ceotenure_temp = (date - becameceo)/365.25
replace ceotenure_temp = round(ceotenure_temp,1)
* tdc1 = total pay according to execucomp (includes: (Salary + Bonus + Other Annual + Restricted Stock Grants + LTIP Payouts + All Other + Value of Option Grants)
* tdc2 = total pay alternative measure, same as tdc1 but includes value of options exercised instead of grants.
* total_curr = salary + bonus, seems equivalent to the 'cashpay' in Forbes.

rename cashpay cashpay_temp
gen cashpay = . 
replace cashpay = cashpay_temp if _merge_forbes == 3
replace cashpay = total_curr if _merge_execucomp == 3

gen totalpay2 = totalpay

replace totalpay = tdc1 if _merge_execucomp == 3 
replace totalpay2 = tdc2 if _merge_execucomp == 3

replace totalpay = totalpay/cpi
replace totalpay = log(totalpay)

replace totalpay2 = totalpay2/cpi
replace totalpay2 = log(totalpay2)

replace cashpay = cashpay/cpi
gen logcashpay = log(cashpay)

* drop outliers in terms of pay - be careful to drop them BY YEAR!

# delimit ; 
* sort fyear
by fyear: egen pay_top = pctile(totalpay2), p(99)
by fyear: egen pay_bottom = pctile(totalpay2), p(1)

drop if totalpay2 >= pay_top | totalpay2 <= pay_bottom
drop pay_top pay_bottom; 

# delimit cr 

* This do file will use totalpay = tdc2 from execucomp as main measure of pay
* Since code was written in terms of totalpay, I just rename totalpay2 accordingly
drop totalpay
rename totalpay2 totalpay

replace tenure = tenure_temp if tenure == . & tenure_temp !=. 
replace ceotenure = ceotenure_temp if ceotenure == . & ceotenure_temp !=. 

drop tenure_temp ceotenure_temp

replace age = age_temp if age == . & age_temp !=. 
gen age2 = age^2
gen tenure2 = tenure^2
gen ceotenure2 = ceotenure^2

******************** Tax Variable definitions **************************

*  Use log(1-mtr) instead of just mtr. 

replace topmtr = log(1-topmtr)

******************** Generate Period Dummies **************************

gen period = . 
replace period = 1 if fyear <= 1986 & fyear != .
replace period = 2 if fyear >= 1987 & fyear != . 
gen post =(fyear >= 1987 & fyear != .) 

******************** General Performance Regressions ******************************************

gen sic2 = substr(sic,1,2)
tab fyear, gen(year)

destring cusip6, replace
quietly tab cusip6, gen (cusip6_)
egen firm = group(cusip6)


local fullcontrols age age2 tenure ceotenure tenure2 ceotenure2 year2-year43
local controls year2-year43
local ceocontrols age age2 tenure ceotenure tenure2 ceotenure2
local cusipcontrols cusip6_2 - cusip6_3887

* Overall performance regressions for both groups

* Instead of fixed effects, demean variables
* Need to demean both the time and the firm dimension. 
* One way to do this is to leave the time dummies, but demean all variables, including the time dummies. 
* need to also demean the dependent variable!
* Saw in statalist that with two way demeaning, the xtdata, fe command does NOT work well. 
* Here it is even more complicated, I have 3 way demeaning: per firm, per time, per period - I want to add interactions of the firm dummies with period too. 
* So I think I want the mean per firm to be per firm and per period. Because this is like running two separate, independent, two way demenaing regressions. 

foreach var in age age2 tenure ceotenure tenure2 ceotenure2 {
bys cusip6 period: egen cl_`var' = mean(`var') 
gen `var'_demeaned = `var' - cl_`var'
}

foreach var of varlist year* {
bys cusip6 period: egen cl_`var' =mean(`var') 
gen demeaned_`var' = `var' - cl_`var'
}

foreach var in totalpay roe logshwealth {
bys cusip6 period: egen cl_`var'=mean(`var')
gen `var'_demeaned = `var' - cl_`var'
}

local ceocontrols_demeaned age_demeaned age2_demeaned tenure_demeaned ceotenure_demeaned tenure2_demeaned ceotenure2_demeaned
local fullcontrols_demeaned age_demeaned age2_demeaned tenure_demeaned ceotenure_demeaned tenure2_demeaned ceotenure2_demeaned demeaned_year1 - demeaned_year43

foreach var in totalpay {

reg `var'_demeaned `fullcontrols_demeaned' roe_demeaned if period == 1 
estimates store roe_general_`var'_1

reg `var'_demeaned `fullcontrols_demeaned' logshwealth_demeaned if period == 1
estimates store sh_general_`var'_1

} 

foreach var in totalpay {

quietly reg `var'_demeaned `fullcontrols_demeaned' roe_demeaned if period == 2
estimates store roe_general_`var'_2

quietly reg `var'_demeaned `fullcontrols_demeaned' logshwealth_demeaned if period == 2
estimates store sh_general_`var'_2

} 

estimates table roe_general_totalpay_1 roe_general_totalpay_2, keep(roe_demeaned) b se p
estimates table sh_general_totalpay_1 sh_general_totalpay_2 , keep(logshwealth_demeaned) b se p 


suest roe_general_totalpay_1 roe_general_totalpay_2
test ([roe_general_totalpay_1_mean]_b[roe_demeaned] = [roe_general_totalpay_2_mean]_b[roe_demeaned])

file open myfile using mytable_800.txt, write replace
file write myfile "ROE test diff" _tab %7.2f ([roe_general_totalpay_2_mean]_b[roe_demeaned]-[roe_general_totalpay_1_mean]_b[roe_demeaned]) "***" _n
file write myfile "ROE test p" _tab %7.2f (r(p)) _n
file close myfile

suest sh_general_totalpay_1 sh_general_totalpay_2 
test ([sh_general_totalpay_1_mean]_b[logshwealth_demeaned] = [sh_general_totalpay_2_mean]_b[logshwealth_demeaned])

file open myfile using mytable_800.txt, write append
file write myfile "Sh Wealth test diff" _tab %7.2f ([sh_general_totalpay_2_mean]_b[logshwealth_demeaned]-[sh_general_totalpay_1_mean]_b[logshwealth_demeaned]) "***" _n
file write myfile "Sh Wealth test p" _tab %7.2f (r(p)) _n
file close myfile


** re estimate all with clustering 

foreach var in totalpay {

reg `var'_demeaned `fullcontrols_demeaned' roe_demeaned if period == 1, cluster(firm)
estimates store roe_general_`var'_1

reg `var'_demeaned `fullcontrols_demeaned' logshwealth_demeaned if period == 1, cluster(firm)
estimates store sh_general_`var'_1

} 

foreach var in totalpay {

quietly reg `var'_demeaned `fullcontrols_demeaned' roe_demeaned if period == 2, cluster(firm)
estimates store roe_general_`var'_2

quietly reg `var'_demeaned `fullcontrols_demeaned' logshwealth_demeaned if period == 2, cluster(firm)
estimates store sh_general_`var'_2

} 

estimates table roe_general_totalpay_1 roe_general_totalpay_2, keep(roe_demeaned) b se p
estimates table sh_general_totalpay_1 sh_general_totalpay_2 , keep(logshwealth_demeaned) b se p 

label variable ni "Net Income"
label variable roe "Net Income/Assets"
label variable logshwealth "Log Shareholder Wealth"

**************************************************************************************************
* Luck measures
**************************************************************************************************

* weight = total asset of firm/total 2-digit industry assets, excluding firm for each year

sort sic2 fyear cusip8
gen at_roe = at
replace at_roe = . if roe ==. 
egen industry_at_roe = total(at_roe), by(sic2 fyear)
gen at_logshwealth = at
replace at_logshwealth = . if logshwealth ==. 
egen industry_at_logshwealth = total(at_logshwealth), by(sic2 fyear)
gen at_ni = at
replace at_ni = . if logshwealth ==. 
egen industry_at_ni = total(at_ni), by(sic2 fyear)

egen industry_at = total(at), by(sic2 fyear)

* take out the firm from industry total:
replace industry_at = industry_at - at 
* Now need to exclude firms which are 'alone' in their industry in a given year, as we have no comparable performance measure.
* drop if industry_at <= 0.01
* Construct weighted variables (only numerator): 
gen roe_industry_temp = roe*at
gen logshwealth_industry_temp = logshwealth*at
gen ni_industry_temp = ni*at
* Summ all weighted variables to get average including all firms:
egen roe_industry_temp2 = total(roe_industry_temp), by(sic2 fyear)
egen logshwealth_industry_temp2 = total(logshwealth_industry_temp), by(sic2 fyear)
egen ni_industry_temp2 = total(ni_industry_temp), by(sic2 fyear)
* Take out firm from average: 
replace roe_industry_temp2 = roe_industry_temp2 - roe_industry_temp
replace logshwealth_industry_temp2 = logshwealth_industry_temp2 - logshwealth_industry_temp
replace ni_industry_temp2 = ni_industry_temp2 - ni_industry_temp
* Divide by denominator excluding firm: 
gen roe_industry = roe_industry_temp2/industry_at
gen logshwealth_industry = logshwealth_industry_temp2/industry_at
gen ni_industry = ni_industry_temp2/industry_at

replace roe_industry = . if industry_at_roe <= 0.01
replace logshwealth_industry = . if industry_at_logshwealth <= 0.01
replace ni_industry = . if industry_at_ni <= 0.01

drop logshwealth_industry_temp roe_industry_temp ni_industry_temp logshwealth_industry_temp2 roe_industry_temp2 ni_industry_temp2

********************************************************************************************************
***************  Direct IV regressions for luck **********************************************************
********************************************************************************************************

quietly xtivreg2 totalpay `fullcontrols' (roe = roe_industry) if period == 1, fe ivar(firm) cluster(firm)
estimates store roe_luck_totalpay_1

quietly xtivreg2 totalpay `fullcontrols' (logshwealth = logshwealth_industry) if period == 1, fe ivar(firm) cluster(firm)
estimates store sh_luck_totalpay_1

estimates table roe_luck_totalpay_1, keep(roe) b se p
estimates table sh_luck_totalpay_1, keep(logshwealth) b se p

quietly xtivreg2 totalpay `fullcontrols' (roe = roe_industry) if period == 2, fe ivar(firm) cluster(firm)
estimates store roe_luck_totalpay_2

quietly xtivreg2 totalpay `fullcontrols' (logshwealth = logshwealth_industry) if period == 2, fe ivar(firm) cluster(firm)
estimates store sh_luck_totalpay_2

estimates table roe_luck_totalpay_2, keep(roe) b se p
estimates table sh_luck_totalpay_2, keep(logshwealth) b se p

* Test for IV

rename tenure2 tenuresq 
rename age2 agesq 
rename ceotenure2 ceotenuresq

foreach var of varlist age agesq tenure ceotenure tenuresq ceotenuresq roe roe_industry logshwealth logshwealth_industry {
	gen `var'1 = `var'*(period==1)
	gen `var'2 = `var'*(period==2)
}

local ceocontrols1 age1 agesq1 tenure1 ceotenure1 tenuresq1 ceotenuresq1
local ceocontrols1 age2 agesq2 tenure2 ceotenure2 tenuresq2 ceotenuresq2


* interact the firm ID variable with time to create a variable at the firmXtime level
egen firmXtime = group(cusip6 period)


* XT iv regression of lhs on t=1 exogenous vars, t=2 exogenous vars, and t=1 and t=2 endogenous vars, instrumented by the t=1 instrument and t=2 instrument
* with FE at the firmXtime level

xtivreg2 totalpay `ceocontrols1' `ceocontrols2' `controls' (roe1 roe2 = roe_industry1 roe_industry2), fe ivar(firmXtime) cluster(firm)
estimates store roe_luck_totalpay

test roe1-roe2 = 0

global diff1 = _b[roe2] - _b[roe1] 
display $diff1

file open myfile using mytable_800.txt, write append
file write myfile "ROE IV test diff" _tab %7.2f ( _b[roe2] - _b[roe1]) "*" _n
file write myfile "ROE IV test p" _tab %7.2f (r(p)) _n
file close myfile

xtivreg2 totalpay `ceocontrols1' `ceocontrols2' `controls' (logshwealth1 logshwealth2 = logshwealth_industry1 logshwealth_industry2), fe ivar(firmXtime) cluster(firm)
estimates store sh_luck_totalpay

test logshwealth1-logshwealth2 = 0

global diff2 = _b[logshwealth2] - _b[logshwealth1]
display $diff2

file open myfile using mytable_800.txt, write append
file write myfile "Sh Wealth IV test diff" _tab %7.2f (_b[logshwealth2] - _b[logshwealth1]) "***" _n
file write myfile "Sh Wealth IV test p" _tab %7.2f (r(p)) _n
file close myfile

outreg2 [roe_general_totalpay_1] roe_demeaned using table_test_800, excel tex replace nocons nonote se r2 bdec(2) ctitle(Log Total Pay, General) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [roe_general_totalpay_2] roe_demeaned using table_test_800, excel tex append nocons nonote se r2 bdec(2) ctitle( , General) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [roe_luck_totalpay_1] roe using table_test_800, excel tex append nocons nonote se r2 bdec(2) ctitle( , Luck) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [roe_luck_totalpay_2] roe using table_test_800, excel tex append nocons nonote se r2 bdec(2) ctitle( , Luck) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [roe_luck_totalpay] roe1 roe2 using table_test_800, excel tex append nocons nonote se r2 bdec(2) ctitle( , Luck) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [sh_general_totalpay_1] logshwealth_demeaned using table_test_800, excel tex append nocons nonote se r2 bdec(2) ctitle(Log Total Pay, General) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [sh_general_totalpay_2] logshwealth_demeaned using table_test_800, excel tex append nocons nonote se r2 bdec(2) ctitle( , General) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [sh_luck_totalpay_1] logshwealth using table_test_800, excel tex append nocons nonote se r2 bdec(2) ctitle( , Luck) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [sh_luck_totalpay_2] logshwealth using table_test_800, excel tex append nocons nonote se r2 bdec(2) ctitle( , Luck) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [sh_luck_totalpay] logshwealth1 logshwealth2 using table_test_800, excel tex append nocons nonote se r2 bdec(2) ctitle( , Luck) slow(1000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)

cap log close
