**************************** TABLES AND FIGURES CONSTRUCTION FOR *******************************
**************************** Optimal Taxation of Top Labor Incomes: **************************** 
**************************** A Tale of Three Elasticities **************************************

**************************** AUTHORS:************************************************************
***********                  Thomas Piketty, Emmanuel Saez and Stefanie Stantcheva          *****
*************************************************************************************************


**************************** DATE: **************************************************************
***********                  November 14th 2012  *****************************************************
*************************************************************************************************

**************************** DESCRIPTION ********************************************************
***********                  This do file performs the regressions related to workers' wages for table 3 
***********                  INPUT files: working.dta contains all the data and is constructed from 
***********                               the raw data through the DO file "Dataset_creation". 
***********                               NOTE: the raw data is NOT publicly available but needs to be downloaded
***********                               from the WRDS website, with user access. The datasets to be downloaded
***********                               are explained in the paper Appendix. The Forbes 800 data is to be requested
***********                               US_CPI.dta: available from the authors
***********                               UStaxes.dta: available from the authors
***********                               NIPA_all wages_clean.dta: available from the authors
***********                  OUTPUT files: table_test_800.xlm, table_test_800.tex
*************************************************************************************************

set mem 1000m
set matsize 1500

estimates drop _all

# delimit cr 

cd "C:\Users\Stefanie\Documents\My Dropbox\thirdelasticity\empirical\Compustat\"

log using BM_10012012_wages.log, replace

use working.dta, clear

sort fyear

merge fyear using US_CPI
drop if _merge == 2
drop _merge

sort fyear
merge fyear using UStaxes
drop if _merge == 2
drop _merge

******************** Financial Variable definitions **************************

* BM measure 1 of performance: net income 
* BM measure 2 of performance: return on equity (called income/assets in their paper)
* at = total assets
* ni = net income
* roe = ni/at
* BM measure 3 of performance: change in shareholder wealth. Change in shareholder wealth = beginning of year equity value times return on common equity
* (will compute both market and book value).
* But since firm fixed effects in the regressions, shareholder wealth should be in levels, but not changes. Hence, shareholder wealth = market value of equity

* Check Kenn French definitions: http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/Data_Library/variable_definitions.html
* Firm value (market) = market value of equity + book value of debt 
* = (number of common shares outstanding (COMPUSTAT item 25) times the average price per share during year (COMPUSTAT item 199)) + book value of debt. 
* Book value of equity is equal to total assets (COMPUSTAT item 6), minus total liabilities (COMPUSTAT item 181) and preferred stock (item 10) 
* plus deferred taxes (item 35) and convertible debt (item 79)). Following Fama and French (2000), when preferred stock is missing, it is replaced 
* by the redemption value of preferred stock (item 56). 
* Firm book value = book value of equity + book value of total debt.
* Total debt is defined as the sum of long-term debt (COMPUSTAT item 9) and the current liabilities (COMPUSTAT item 34).

* Common shares outstanding: csho
* Price close annual calendar:   prcc_c
* Total liabilities: lt
* Debt in current liabilities : dlc
* Preferred stock at redemption value : pstkrv
* Net Deferred tax liability: txndbl
* Debt convertible: dcvt
* labor and related expenses: xlr
* only wage and salaries expenses: xstfws ALL MISSINGS
* total employees: emp

* Constructed variables: 
* Market value of equity = mve = shareholder wealth
* Market value of firm = mvf
* Book value of firm = bvf
* Book value of equity = bve
* Change in Shareholder wealth = roe*mve
* average wage in firm: wage = xlr/emp 
* other measure using only wages and salaries: wage2 = xstfws/emp
*************************************************************

* cpi = US CPI index
replace cpi = cpi/100

replace ni = ni/cpi
replace at = at/cpi
gen roe = ni/at
gen mve = csho*(prcc_c/cpi)
* gen debt =  dlc/cpi
* gen mvf = mve + debt
* gen bve = (at - lt - pstkrv + txndbl + dcvt)/cpi 
* gen bvf =  bve + debt
* gen dshwealth = roe*mve
gen shwealth = mve
gen logshwealth = log(shwealth)
* replace xlr = xlr/cpi
* replace xstfws = xstfws/cpi
* gen wage = xlr/emp
* gen lwage = log(wage)

********************************************************************
********************************************************************

*** Careful: for convenience of the code, I rename Net Income "ROE"

drop roe
gen roe = ni
replace roe = log(roe)

* Try to replace log shwealth with its deviation from mean, by year
* NOTE: I dont think this makes too much sense!

* sort fyear
* by fyear: egen logshwealth_average = mean(logshwealth)
* replace logshwealth = logshwealth- logshwealth_average
* by fyear: egen roe_average = mean(roe)
* replace roe = roe - roe_average

* drop outliers

sort fyear
by fyear: egen roe_top = pctile(roe), p(99.5)
by fyear: egen roe_bottom = pctile(roe), p(0.5)

replace roe = . if roe >= roe_top | roe <= roe_bottom
drop roe_top roe_bottom

sort fyear
by fyear: egen lsh_top = pctile(logshwealth), p(99.5)
by fyear: egen lsh_bottom = pctile(logshwealth), p(0.5)

replace logshwealth = . if logshwealth >= lsh_top | logshwealth <= lsh_bottom
drop lsh_top lsh_bottom


******************** CEO variables definitions ****************

* Make names of execucomp and Forbes CEO variables consistent.
* Drop those executives who are non CEOs in execucomp

* This should guarantee at most one observation per firm per year. (checked - is true)
drop if _merge_execucomp == 3 & ceoann == ""

* Forbes variables: 
* cashpay, optiongains,	otherpay, totalpay ( I *think* in thousands).
* tenure, ceotenure, age_temp

* Execucomp variables: 
* age
* Tenure in company: 
gen date = mdy(12,31,fyear)
gen tenure_temp = (date - joined_co)/365.25 
replace tenure_temp = round(tenure_temp,1)
* Tenure as CEO: 
gen ceotenure_temp = (date - becameceo)/365.25
replace ceotenure_temp = round(ceotenure_temp,1)
* tdc1 = total pay according to execucomp (includes: (Salary + Bonus + Other Annual + Restricted Stock Grants + LTIP Payouts + All Other + Value of Option Grants)
* tdc2 = total pay alternative measure, same as tdc1 but includes value of options exercised instead of grants.
* total_curr = salary + bonus, seems equivalent to the 'cashpay' in Forbes.

rename cashpay cashpay_temp
gen cashpay = . 
replace cashpay = cashpay_temp if _merge_forbes == 3
replace cashpay = total_curr if _merge_execucomp == 3

gen totalpay2 = totalpay

replace totalpay = tdc1 if _merge_execucomp == 3 
replace totalpay2 = tdc2 if _merge_execucomp == 3

replace totalpay = totalpay/cpi
replace totalpay = log(totalpay)

replace totalpay2 = totalpay2/cpi
replace totalpay2 = log(totalpay2)

replace cashpay = cashpay/cpi
gen logcashpay = log(cashpay)

* This do file will use totalpay = tdc2 from execucomp as main measure of pay

* drop outliers in terms of pay
# delimit ; 
* gen totalpay_temp = exp(totalpay)
gen totalpay_temp2 = exp(totalpay2)

by fyear: egen pay_top = pctile(totalpay_temp2), p(99)
by fyear: egen pay_bottom = pctile(totalpay_temp2), p(1)

drop if totalpay_temp2 >= pay_top | totalpay_temp2 <= pay_bottom
drop pay_top pay_bottom
drop totalpay totalpay_temp totalpay_temp2 ; 

# delimit cr

drop totalpay
rename totalpay2 totalpay

replace tenure = tenure_temp if tenure == . & tenure_temp !=. 
replace ceotenure = ceotenure_temp if ceotenure == . & ceotenure_temp !=. 

drop tenure_temp ceotenure_temp

replace age = age_temp if age == . & age_temp !=. 
gen age2 = age^2
gen tenure2 = tenure^2
gen ceotenure2 = ceotenure^2

******************** Tax Variable definitions **************************

*  Use log(1-mtr) instead of just mtr. 

replace topmtr = log(1-topmtr)


******************** Generate Period Dummies **************************

gen period = . 
replace period = 1 if fyear <= 1986 & fyear != .
replace period = 2 if fyear >= 1987 & fyear != . 
gen post =(fyear >= 1987 & fyear != .) 


******************** General Performance Regressions ******************************************

gen sic2 = substr(sic,1,2)
tab fyear, gen(year)

sort sic2 fyear
merge sic2 fyear using "NIPA_all wages_clean.dta"
keep if _merge == 3
drop _merge

* Need to deflate wages
replace ind_wage = ind_wage/cpi
gen lind_wage = log(ind_wage)

destring cusip6, replace
quietly tab cusip6, gen (cusip6_)

local fullcontrols age age2 tenure ceotenure tenure2 ceotenure2 year2-year43
local controls year2-year43
local ceocontrols age age2 tenure ceotenure tenure2 ceotenure2

label variable ni "Net Income"
label variable roe "Net Income/Assets"
label variable logshwealth "Log Shareholder Wealth"

**************************************************************************************************
* Luck measures for wages
**************************************************************************************************

* When constructing the luck measure, better not to count the assets of those companies which have no observations for net income or log sh wealth, 
* to avoid inflating the assets (denominator) without inflating numerator. 

sort sic2 fyear cusip8
gen at_roe = at
replace at_roe = . if roe ==. 
egen industry_at_roe = total(at_roe), by(sic2 fyear)
gen at_logshwealth = at
replace at_logshwealth = . if logshwealth ==. 
egen industry_at_logshwealth = total(at_logshwealth), by(sic2 fyear)
gen at_ni = at
replace at_ni = . if logshwealth ==. 
egen industry_at_ni = total(at_ni), by(sic2 fyear)

* Construct weighted variables (only numerator): 
gen roe_industry_temp = roe*at
gen logshwealth_industry_temp = logshwealth*at
gen ni_industry_temp = ni*at
* Summ all weighted variables to get average including all firms:
egen roe_industry_temp2 = total(roe_industry_temp), by(sic2 fyear)
egen logshwealth_industry_temp2 = total(logshwealth_industry_temp), by(sic2 fyear)
egen ni_industry_temp2 = total(ni_industry_temp), by(sic2 fyear)
* Divide by appropriate denominator including firm: 
gen roe_industry = roe_industry_temp2/industry_at_roe
gen logshwealth_industry = logshwealth_industry_temp2/industry_at_logshwealth
gen ni_industry = ni_industry_temp2/industry_at_ni

replace roe_industry = . if industry_at_roe <= 0.01 
replace logshwealth_industry = . if industry_at_logshwealth <= 0.01 
replace ni_industry = . if industry_at_ni <= 0.01

drop logshwealth_industry_temp roe_industry_temp ni_industry_temp logshwealth_industry_temp2 roe_industry_temp2 ni_industry_temp2 industry_at_roe industry_at_logshwealth industry_at_ni

keep roe_industry logshwealth_industry ni_industry lind_wage ind_wage year* sic2 topmtr fyear period

save working_wages.dta, replace

********************************************************************************************************
*************** Making tables for publication **********************************************************
********************************************************************************************************

use working_wages.dta, replace 

collapse roe_industry logshwealth_industry ni_industry lind_wage ind_wage year1-year43 topmtr period, by(sic2 fyear)

egen ind = group(sic2)

quietly xtreg lind_wage `controls' roe_industry if period == 1, fe i(ind) cluster(ind)
estimates store roe_luck_wage_1

quietly xtreg lind_wage `controls' logshwealth_industry if period == 1, fe i(ind) cluster(ind)
estimates store sh_luck_wage_1

estimates table roe_luck_wage_1 , keep(roe_industry) b se p
estimates table sh_luck_wage_1, keep(logshwealth_industry) b se p

quietly xtreg lind_wage `controls' roe_industry if period == 2, fe i(ind) cluster(ind)
estimates store roe_luck_wage_2

quietly xtreg lind_wage `controls' logshwealth_industry if period == 2, fe i(ind) cluster(ind)
estimates store sh_luck_wage_2

estimates table roe_luck_wage_2 , keep(roe_industry) b se p
estimates table sh_luck_wage_2, keep(logshwealth_industry) b se p

outreg2 [roe_luck_wage_1] roe_industry using table_wages, excel tex replace nocons nonote se r2 bdec(2) ctitle(Wages, Luck) slow(2000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [roe_luck_wage_2] roe_industry using table_wages, excel tex append nocons nonote se r2 bdec(2) ctitle(Wages, Luck) slow(2000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [sh_luck_wage_1] logshwealth_industry using table_wages, excel tex append nocons nonote se r2 bdec(2) ctitle(Wages, Luck) slow(2000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)
outreg2 [sh_luck_wage_2] logshwealth_industry using table_wages, excel tex append nocons nonote se r2 bdec(2) ctitle( Wages, Luck) slow(2000) label alpha(0.01, 0.05, 0.10) symbol(***, **, *)


****** Test for difference *********************************

** Re estimate models without cluster option to be able to use suest and need to demean it (FEs not allowed with suest)

foreach var of varlist year* {
bys ind period: egen cl_`var' =mean(`var') 
gen demeaned_`var' = `var' - cl_`var'
}

foreach var in lind_wage roe_industry logshwealth_industry {
bys ind period: egen cl_`var'=mean(`var')
gen `var'_demeaned = `var' - cl_`var'
}

local controls_demeaned demeaned_year1 - demeaned_year43

quietly reg lind_wage_demeaned `controls_demeaned' roe_industry_demeaned if period == 1
estimates store roe_luck_wage_1

quietly reg lind_wage_demeaned `controls_demeaned' logshwealth_industry_demeaned if period == 1
estimates store sh_luck_wage_1

estimates table roe_luck_wage_1 , keep(roe_industry_demeaned) b se p
estimates table sh_luck_wage_1, keep(logshwealth_industry_demeaned) b se p

quietly reg lind_wage_demeaned `controls_demeaned' roe_industry_demeaned if period == 2
estimates store roe_luck_wage_2

quietly reg lind_wage_demeaned `controls_demeaned' logshwealth_industry_demeaned if period == 2
estimates store sh_luck_wage_2

estimates table roe_luck_wage_2 , keep(roe_industry_demeaned) b se p
estimates table sh_luck_wage_2, keep(logshwealth_industry_demeaned) b se p

suest roe_luck_wage_1 roe_luck_wage_2, vce(cluster ind)
test ([roe_luck_wage_1_mean]_b[roe_industry_demeaned] = [roe_luck_wage_2_mean]_b[roe_industry_demeaned])

file open myfile using mytable_wages.txt, write replace
file write myfile "ROE test diff" _tab %7.3f ([roe_luck_wage_2_mean]_b[roe_industry_demeaned] - [roe_luck_wage_1_mean]_b[roe_industry_demeaned]) _n
file write myfile "ROE test p" _tab %7.2f (r(p)) _n
file close myfile

suest sh_luck_wage_1 sh_luck_wage_2 , vce(cluster ind)
test ([sh_luck_wage_1_mean]_b[logshwealth_industry_demeaned] = [sh_luck_wage_2_mean]_b[logshwealth_industry_demeaned])

file open myfile using mytable_wages.txt, write append
file write myfile "Sh Wealth test diff" _tab %7.3f ([sh_luck_wage_2_mean]_b[logshwealth_industry_demeaned]-[sh_luck_wage_1_mean]_b[logshwealth_industry_demeaned]) _n
file write myfile "Sh Wealth test p" _tab %7.2f (r(p)) _n
file close myfile

cap log close

